@@ -1,4 +1,6 @@
-from saptiva_agents.base._chat_agent import Response, ChatAgent
+from autogen_agentchat.base import Response
+
+from saptiva_agents.base._chat_agent import ChatAgent
 from saptiva_agents.base._classes import SaptivaAIChatCompletionClient, SaptivaAIBase, SaptivaAgentsFramework
 from saptiva_agents.base._handoff import Handoff
 from saptiva_agents.base._termination import (TerminatedException, TerminationCondition, AndTerminationCondition,
