@@ -1,5 +1,6 @@
 from autogen_core.tools import ToolSchema
 
+from saptiva_agents.tools._agent import AgentTool
 from saptiva_agents.tools._base import BaseTool, BaseToolWithState, Tool
 from saptiva_agents.tools._function_tool import FunctionTool
 from saptiva_agents.tools.tools import (
@@ -29,6 +30,7 @@ __all__ = [
     "obtener_texto_en_documento",
     "consultar_curp_get",
     "consultar_curp_post",
-    "consultar_cfdi"
+    "consultar_cfdi",
+    "AgentTool"
 ]
 
